pub struct PlayerSet {Show 13 fields
pub timestamp: Option<String>,
pub own_rating_value: Option<f32>,
pub own_rating_deviation: Option<f32>,
pub floor: Option<String>,
pub opponent_name: Option<String>,
pub opponent_platform: Option<String>,
pub opponent_id: Option<i64>,
pub opponent_character: Option<String>,
pub opponent_character_short: Option<String>,
pub opponent_rating_value: Option<f32>,
pub opponent_rating_deviation: Option<f32>,
pub result_win: Option<bool>,
pub odds: Option<f32>,
}Fields
timestamp: Option<String>Timestamp of the match
own_rating_value: Option<f32>Player’s rating value at the time of the match
own_rating_deviation: Option<f32>Player’s rating deviation at the time of the match
floor: Option<String>Floor of the match (e.g., "Celestial")
opponent_name: Option<String>Opponent’s name
opponent_platform: Option<String>Opponent’s platform (PS, XB, PC)
opponent_id: Option<i64>Opponent’s ID
opponent_character: Option<String>Opponent’s character (full name)
opponent_character_short: Option<String>Opponent’s character (short name)
opponent_rating_value: Option<f32>Opponent’s rating value at the time of the match
opponent_rating_deviation: Option<f32>Opponent’s rating deviation at the time of the match
result_win: Option<bool>Whether the player won the match
odds: Option<f32>Player’s odds of winning the match
Implementations